Crate kg

Crate kg 

Re-exports

pub use output::FindMode;

Modules

output

Structs

Edge
EdgeProperties
GraphFile
Metadata
Node
NodeProperties

Functions

default_graph_root
Returns the default graph root directory for this environment.
resolve_graph_path
Resolve a graph identifier/path to an on-disk JSON file.
run
Run kg with CLI arguments, printing the result to stdout.
run_args
Run kg with CLI arguments, returning the rendered output as a string.
run_args_safe
Run kg with CLI arguments, returning errors as Result instead of exiting.