Re-exports
pub use output::FindMode;
Modules
Structs
Functions
- default_
graph_ root - Returns the default graph root directory for this environment.
- resolve_
graph_ path - Resolve a graph identifier/path to an on-disk JSON file.
- run
- Run kg with CLI arguments, printing the result to stdout.
- run_
args - Run kg with CLI arguments, returning the rendered output as a string.
- run_
args_ safe - Run kg with CLI arguments, returning errors as Result instead of exiting.